---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Import '...'
3. Run '...'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**System specifications (please complete the following information):**
- OS: [e.g. iOS]
- Python version: [e.g. 3.6]
- pulse2percept version: [e.g. 0.4]

**Additional context**
Add any other context about the problem here.
